@@ -15,7 +15,7 @@ use Path::Class;
 use File::chdir;
 use Group::Git::Repo;
 
-our $VERSION     = version->new('0.0.4');
+our $VERSION     = version->new('0.0.5');
 our $AUTOLOAD;
 
 has conf => (
@@ -61,8 +61,13 @@ sub _repos {
 
     for my $config (map {file $_} glob('*/.git/config')) {
         my ($url) = grep {/^\s*url\s*=\s*/} $config->slurp;
-        chomp $url;
-        $url =~ s/^\s*url\s*=\s*//;
+        if ($url) {
+            chomp $url;
+            $url =~ s/^\s*url\s*=\s*//;
+        }
+        else {
+            $url = '';
+        }
 
         $repos{ $config->parent->parent->basename } = Group::Git::Repo->new(
             name => $config->parent->parent->basename,
@@ -110,7 +115,7 @@ Group::Git - Base module for group of git repository operations.
 
 =head1 VERSION
 
-This documentation refers to Group::Git version 0.0.4.
+This documentation refers to Group::Git version 0.0.5.
 
 =head1 SYNOPSIS
 
